Treasury Analytics Core
  • Home
  • API Reference
  • Examples
  • Credentials
  • Global Settings
  1. API Reference
  2. Scripts
  3. create_project
  • Overview
    • Treasury Analytics Core
  • Credential Management
    • Secure Credential Management
    • Global Settings
  • Examples
    • Example Projects
  • API Reference
    • Function reference
    • Core Components
      • FinanceDataEngine
      • engine_factory
      • engine
      • database
      • cache
      • processor
      • analyzer
    • Configuration
      • settings
      • settings_factory
      • global_settings_manager
    • Utilities
      • credentials
      • dataframe_utils
      • setup_logging
      • env_checker
      • query_timer
      • setup_helper
      • logging
      • constants
      • types
    • Scripts
      • configure_db
      • create_project
      • manage_settings

On this page

  • create_project
    • Functions
      • create_project
      • create_readme
      • create_requirements
      • create_sample_script
      • create_virtualenv
      • main
      • parse_args

Other Formats

  • Github (GFM)
  1. API Reference
  2. Scripts
  3. create_project

create_project

scripts.create_project

Project Creation Script for nova_fde

Creates a new project structure with the necessary directories and configuration.

Usage: python -m nova_fde.scripts.create_project [options] PROJECT_PATH

Options: –no-global-settings Don’t use global settings –template TYPE Project template to use (default, analysis, reporting) –venv Create a virtual environment

Functions

Name Description
create_project Create a new project at the specified path.
create_readme Create README.md for the project.
create_requirements Create requirements.txt for the project.
create_sample_script Create a sample script for the project.
create_virtualenv Create a virtual environment for the project.
main Main entry point for the script.
parse_args Parse command line arguments.

create_project

scripts.create_project.create_project(
    project_path,
    use_global_settings=True,
    template='default',
    create_venv=False,
)

Create a new project at the specified path.

create_readme

scripts.create_project.create_readme(
    project_path,
    template,
    use_global_settings,
)

Create README.md for the project.

create_requirements

scripts.create_project.create_requirements(project_path, template)

Create requirements.txt for the project.

create_sample_script

scripts.create_project.create_sample_script(
    project_path,
    template,
    use_global_settings,
)

Create a sample script for the project.

create_virtualenv

scripts.create_project.create_virtualenv(project_path)

Create a virtual environment for the project.

main

scripts.create_project.main()

Main entry point for the script.

parse_args

scripts.create_project.parse_args()

Parse command line arguments.

configure_db
manage_settings
 
 
  • Built with [Quarto](https://quarto.org/) and [quartodoc](https://machow.github.io/quartodoc/)