engine_factory
core.engine_factory
Factory module for creating FinanceDataEngine instances with different configurations.
Classes
| Name | Description |
|---|---|
| EngineFactory | Factory for creating FinanceDataEngine instances with different configurations. |
| GlobalSettings | Manager for global settings across projects. |
EngineFactory
core.engine_factory.EngineFactory()Factory for creating FinanceDataEngine instances with different configurations.
Methods
| Name | Description |
|---|---|
| check_credentials | Check if credentials are available in any storage location. |
| create_with_auto_auth | A fixed version of create_with_auto_auth that correctly loads credentials. |
check_credentials
core.engine_factory.EngineFactory.check_credentials(
console=None,
keyring_service='nova_fde',
)Check if credentials are available in any storage location.
create_with_auto_auth
core.engine_factory.EngineFactory.create_with_auto_auth(
project_root=None,
console=None,
keyring_service='nova_fde',
keyring_username=None,
check_password_expiry=True,
global_settings_path=None,
)A fixed version of create_with_auto_auth that correctly loads credentials.
GlobalSettings
core.engine_factory.GlobalSettings(self, settings_path=None)Manager for global settings across projects.
Methods
| Name | Description |
|---|---|
| check_password_expiration | Check password expiration status. |
| get_db_settings | Get database-specific settings. |
| get_password_meta | Get password metadata for expiration tracking. |
| get_settings | Get the global settings. |
| load_settings | Load settings from the global settings file. |
check_password_expiration
core.engine_factory.GlobalSettings.check_password_expiration()Check password expiration status.
get_db_settings
core.engine_factory.GlobalSettings.get_db_settings()Get database-specific settings.
get_password_meta
core.engine_factory.GlobalSettings.get_password_meta()Get password metadata for expiration tracking.
get_settings
core.engine_factory.GlobalSettings.get_settings()Get the global settings.
load_settings
core.engine_factory.GlobalSettings.load_settings()Load settings from the global settings file.
Functions
| Name | Description |
|---|---|
| fixed_create_with_auto_auth | A fixed version of create_with_auto_auth that correctly loads credentials. |
fixed_create_with_auto_auth
core.engine_factory.fixed_create_with_auto_auth(
project_root=None,
console=None,
keyring_service='nova_fde',
keyring_username=None,
check_password_expiry=True,
global_settings_path=None,
)A fixed version of create_with_auto_auth that correctly loads credentials.