Manages global settings across projects using nova_fde.
This class provides functionality to store and retrieve database settings, project templates, and other configuration that should be shared across multiple projects.
Parameters
Name
Type
Description
Default
settings_path
str or Path
Path to global settings file. If not provided, default locations are searched.
None
Attributes
Name
Type
Description
DEFAULT_SETTINGS_PATHS
list
List of default paths to search for global settings in order of preference.
settings_path
Path
Path to the global settings file.
_settings
dict
Cached settings data.
Notes
Global settings are stored in YAML or JSON format in one of the following locations by default (in order of preference): - ~/.nova_fde/settings.yaml - ~/.config/nova_fde/settings.yaml - ~/.nova_fde/settings.json - ~/.config/nova_fde/settings.json
Dictionary containing password expiration information including: - status: ‘expired’, ‘warning’, or ‘ok’ - days_remaining: Number of days until expiration - expiry_date: Date of expiration - last_updated: Date when password was last updated